summaryrefslogtreecommitdiffstats
path: root/src/connector.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/connector.h')
-rw-r--r--src/connector.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/connector.h b/src/connector.h
index 740b5b7..002301d 100644
--- a/src/connector.h
+++ b/src/connector.h
@@ -104,11 +104,11 @@ public:
*/
void setSemiHidden( bool semiHidden );
/**
* Sets the container tqparent (i.e. the container of the tqparent item)
*/
void setParentContainer( const TQString &cnItemId );
/**
* Returns a pointer to the tqparent item container
*/
CNItem *parentContainer() const { return p_parentContainer; }
/**
@@ -190,7 +190,7 @@ class ConnectorLine : public TQObject, public TQCanvasLine
{
public:
ConnectorLine( Connector *connector );
- Connector *tqparent() const { return p_connector; }
+ Connector *parent() const { return p_connector; }
virtual int rtti() const;
protected:
@@ -104,11 +104,11 @@ public:
void setSemiHidden( bool semiHidden );
/**
- * Sets the container tqparent (i.e. the container of the tqparent item)
+ * Sets the container parent (i.e. the container of the parent item)
*/
void setParentContainer( const TQString &cnItemId );
@@ -104,11 +104,11 @@ public:
void setParentContainer( const TQString &cnItemId );
/**
- * Returns a pointer to the tqparent item container
+ * Returns a pointer to the parent item container
*/
CNItem *parentContainer() const { return p_parentContainer; }